@@ -14,7 +14,6 @@
 
 """Tests for logging configuration via ZConfig."""
 
-import cStringIO as StringIO
 import doctest
 import logging
 import os
@@ -28,6 +27,11 @@ from ZConfig.components.logger import datatypes
 from ZConfig.components.logger import handlers
 from ZConfig.components.logger import loghandler
 
+try:
+    import StringIO as StringIO
+except ImportError:
+    # Python 3 support.
+    import io as StringIO
 
 class CustomFormatter(logging.Formatter):
     def formatException(self, ei):
@@ -41,6 +45,11 @@ class CustomFormatter(logging.Formatter):
         return sio.getvalue() + "... Don't panic!"
 
 
+def read_file(filename):
+    with open(filename) as f:
+        return f.read()
+
+
 class LoggingTestHelper:
 
     # Not derived from unittest.TestCase; some test runners seem to
@@ -99,7 +108,7 @@ class LoggingTestHelper:
     def get_config(self, text):
         conf, handler = ZConfig.loadConfigFile(self.get_schema(),
                                                StringIO.StringIO(text))
-        self.assert_(not handler)
+        self.assertTrue(not handler)
         return conf
 
 
@@ -122,6 +131,8 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
                      "critical"]:
             self.assertEqual(convert(name), convert(name.upper()))
         self.assertRaises(ValueError, convert, "hopefully-not-a-valid-value")
+        self.assertEqual(convert('10'), 10)
+        self.assertRaises(ValueError, convert, '100')
 
     def test_http_method(self):
         convert = handlers.get_or_post
@@ -144,15 +155,14 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
 
     def test_config_without_logger(self):
         conf = self.get_config("")
-        self.assert_(conf.eventlog is None)
+        self.assertTrue(conf.eventlog is None)
 
     def test_config_without_handlers(self):
         logger = self.check_simple_logger("<eventlog/>")
         # Make sure there's a NullHandler, since a warning gets
         # printed if there are no handlers:
         self.assertEqual(len(logger.handlers), 1)
-        self.assert_(isinstance(logger.handlers[0],
-                                loghandler.NullHandler))
+        self.assertTrue(isinstance(logger.handlers[0], loghandler.NullHandler))
 
     def test_with_logfile(self):
         fn = self.mktemp()
@@ -164,7 +174,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
                                           "</eventlog>" % fn)
         logfile = logger.handlers[0]
         self.assertEqual(logfile.level, logging.DEBUG)
-        self.assert_(isinstance(logfile, loghandler.FileHandler))
+        self.assertTrue(isinstance(logfile, loghandler.FileHandler))
         logger.removeHandler(logfile)
         logfile.close()
 
@@ -188,7 +198,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
         self.assertEqual(logfile.level, logging.DEBUG)
         self.assertEqual(logfile.backupCount, 10)
         self.assertEqual(logfile.maxBytes, 5*1024*1024)
-        self.assert_(isinstance(logfile, loghandler.RotatingFileHandler))
+        self.assertTrue(isinstance(logfile, loghandler.RotatingFileHandler))
         logger.removeHandler(logfile)
         logfile.close()
 
@@ -206,7 +216,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
         self.assertEqual(logfile.level, logging.DEBUG)
         self.assertEqual(logfile.backupCount, 11)
         self.assertEqual(logfile.interval, 86400)
-        self.assert_(isinstance(logfile, loghandler.TimedRotatingFileHandler))
+        self.assertTrue(isinstance(logfile, loghandler.TimedRotatingFileHandler))
         logger.removeHandler(logfile)
         logfile.close()
 
@@ -225,7 +235,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
         self.assertEqual(logfile.level, logging.DEBUG)
         self.assertEqual(logfile.backupCount, 11)
         self.assertEqual(logfile.interval, 86400*3)
-        self.assert_(isinstance(logfile, loghandler.TimedRotatingFileHandler))
+        self.assertTrue(isinstance(logfile, loghandler.TimedRotatingFileHandler))
         logger.removeHandler(logfile)
         logfile.close()
 
@@ -254,7 +264,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
               </logfile>
             </eventlog>
             """ % name.upper())
-        self.assert_(conf.eventlog is not None)
+        self.assertTrue(conf.eventlog is not None)
         # The factory has already been created; make sure it picks up
         # the stderr we set here when we create the logger and
         # handlers:
@@ -264,8 +274,8 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
             logger = conf.eventlog()
         finally:
             setattr(sys, name, old_stream)
-        logger.warn("woohoo!")
-        self.assert_(sio.getvalue().find("woohoo!") >= 0)
+        logger.warning("woohoo!")
+        self.assertTrue(sio.getvalue().find("woohoo!") >= 0)
 
     def test_custom_formatter(self):
         old_stream = sys.stdout
@@ -288,10 +298,11 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
             raise KeyError
         except KeyError:
             logger.exception("testing a KeyError")
-        self.assert_(sio.getvalue().find("KeyError") >= 0)
-        self.assert_(sio.getvalue().find("Don't panic") >= 0)
+        self.assertTrue(sio.getvalue().find("KeyError") >= 0)
+        self.assertTrue(sio.getvalue().find("Don't panic") >= 0)
 
     def test_with_syslog(self):
+        import socket
         logger = self.check_simple_logger("<eventlog>\n"
                                           "  <syslog>\n"
                                           "    level error\n"
@@ -300,7 +311,12 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
                                           "</eventlog>")
         syslog = logger.handlers[0]
         self.assertEqual(syslog.level, logging.ERROR)
-        self.assert_(isinstance(syslog, loghandler.SysLogHandler))
+        self.assertTrue(isinstance(syslog, loghandler.SysLogHandler))
+        syslog.close() # avoid ResourceWarning
+        try:
+            syslog.socket.close() # ResourceWarning under 3.2
+        except socket.SocketError:
+            pass
 
     def test_with_http_logger_localhost(self):
         logger = self.check_simple_logger("<eventlog>\n"
@@ -316,7 +332,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
         self.assertEqual(handler.url, "/")
         self.assertEqual(handler.level, logging.ERROR)
         self.assertEqual(handler.method, "POST")
-        self.assert_(isinstance(handler, loghandler.HTTPHandler))
+        self.assertTrue(isinstance(handler, loghandler.HTTPHandler))
 
     def test_with_http_logger_remote_host(self):
         logger = self.check_simple_logger("<eventlog>\n"
@@ -332,7 +348,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
         self.assertEqual(handler.url, "/log/")
         self.assertEqual(handler.level, logging.NOTSET)
         self.assertEqual(handler.method, "GET")
-        self.assert_(isinstance(handler, loghandler.HTTPHandler))
+        self.assertTrue(isinstance(handler, loghandler.HTTPHandler))
 
     def test_with_email_notifier(self):
         logger = self.check_simple_logger("<eventlog>\n"
@@ -366,7 +382,7 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
                 raise
         else:
             # This path must only be reached with python >=2.6
-            self.assert_(sys.version_info >= (2, 6))
+            self.assertTrue(sys.version_info >= (2, 6))
             handler = logger.handlers[0]
             self.assertEqual(handler.toaddrs, ["sysadmin@example.com"])
             self.assertEqual(handler.fromaddr, "zlog-user@example.com")
@@ -399,10 +415,10 @@ class TestConfig(LoggingTestHelper, unittest.TestCase):
 
     def check_simple_logger(self, text, level=logging.INFO):
         conf = self.get_config(text)
-        self.assert_(conf.eventlog is not None)
+        self.assertTrue(conf.eventlog is not None)
         self.assertEqual(conf.eventlog.level, level)
         logger = conf.eventlog()
-        self.assert_(isinstance(logger, logging.Logger))
+        self.assertTrue(isinstance(logger, logging.Logger))
         self.assertEqual(len(logger.handlers), 1)
         return logger
 
@@ -488,14 +504,14 @@ class TestReopeningRotatingLogfiles(LoggingTestHelper, unittest.TestCase):
         h.close()
 
         # Check that the messages are in the right files::
-        text1 = open(nfn1).read()
-        text2 = open(nfn2).read()
-        text3 = open(fn).read()
-        self.assert_("message 1" in text1)
-        self.assert_("message 2" in text1)
-        self.assert_("message 3" in text2)
-        self.assert_("message 4" in text2)
-        self.assert_("message 5" in text3)
+        text1 = read_file(nfn1)
+        text2 = read_file(nfn2)
+        text3 = read_file(fn)
+        self.assertTrue("message 1" in text1)
+        self.assertTrue("message 2" in text1)
+        self.assertTrue("message 3" in text2)
+        self.assertTrue("message 4" in text2)
+        self.assertTrue("message 5" in text3)
 
     def test_logfile_reopening(self):
         #
@@ -537,9 +553,9 @@ class TestReopeningRotatingLogfiles(LoggingTestHelper, unittest.TestCase):
         for fn in paths:
             fn1 = fn + ".1"
             fn2 = fn + ".2"
-            self.assert_(os.path.isfile(fn), "%r must exist" % fn)
-            self.assert_(os.path.isfile(fn1), "%r must exist" % fn1)
-            self.assert_(os.path.isfile(fn2), "%r must exist" % fn2)
+            self.assertTrue(os.path.isfile(fn), "%r must exist" % fn)
+            self.assertTrue(os.path.isfile(fn1), "%r must exist" % fn1)
+            self.assertTrue(os.path.isfile(fn2), "%r must exist" % fn2)
         #
         # Clean up:
         for logger in conf.loggers:
@@ -615,11 +631,11 @@ class TestReopeningLogfiles(TestReopeningRotatingLogfiles):
         #
         # We should now have all nine files:
         for fn in paths:
-            self.assert_(os.path.isfile(fn), "%r must exist" % fn)
+            self.assertTrue(os.path.isfile(fn), "%r must exist" % fn)
         for fn in npaths1:
-            self.assert_(os.path.isfile(fn), "%r must exist" % fn)
+            self.assertTrue(os.path.isfile(fn), "%r must exist" % fn)
         for fn in npaths2:
-            self.assert_(os.path.isfile(fn), "%r must exist" % fn)
+            self.assertTrue(os.path.isfile(fn), "%r must exist" % fn)
         #
         # Clean up:
         for logger in conf.loggers:
