@@ -58,7 +58,7 @@ class DatatypeTestCase(unittest.TestCase):
 
     def test_datatype_boolean(self):
         convert = self.types.get("boolean")
-        check = self.assert_
+        check = self.assertTrue
         raises = self.assertRaises
 
         check(convert("on"))
@@ -78,7 +78,7 @@ class DatatypeTestCase(unittest.TestCase):
         raises = self.assertRaises
 
         eq(convert("1"), 1.0)
-        self.assert_(type(convert(1)) is type(1.0))
+        self.assertTrue(type(convert(1)) is type(1.0))
         eq(convert("1.1"), 1.1)
         eq(convert("50.50"), 50.50)
         eq(convert("-50.50"), -50.50)
@@ -122,12 +122,12 @@ class DatatypeTestCase(unittest.TestCase):
     def assert_ascii_equal(self, convert, value):
         v = convert(value)
         self.assertEqual(v, value)
-        self.assert_(isinstance(v, str))
+        self.assertTrue(isinstance(v, str))
         if have_unicode:
             unicode_value = unicode(value)
             v = convert(unicode_value)
             self.assertEqual(v, value)
-            self.assert_(isinstance(v, str))
+            self.assertTrue(isinstance(v, str))
 
     def check_never_namelike(self, convert):
         raises = self.assertRaises
@@ -225,11 +225,6 @@ class DatatypeTestCase(unittest.TestCase):
         eq(convert('65535'), 65535)
         eq(convert('65536'), 65536)
 
-        big = sys.maxint + 1L  # Python 2.1 needs the L suffix here
-        s = str(big)           # s won't have the suffix
-        eq(convert(s), big)
-        eq(convert("-" + s), -big)
-
         raises(ValueError, convert, 'abc')
         raises(ValueError, convert, '-0xabc')
         raises(ValueError, convert, '')
@@ -283,8 +278,8 @@ class DatatypeTestCase(unittest.TestCase):
             self.assertEqual(a1.family, socket.AF_UNIX)
             self.assertEqual(a2.family, socket.AF_UNIX)
         else:
-            self.assert_(a1.family is None)
-            self.assert_(a2.family is None)
+            self.assertTrue(a1.family is None)
+            self.assertTrue(a2.family is None)
 
     def test_ipaddr_or_hostname(self):
         convert = self.types.get('ipaddr-or-hostname')
@@ -349,12 +344,12 @@ class DatatypeTestCase(unittest.TestCase):
         eq(convert('128'), 128)
         eq(convert('128KB'), 128*1024)
         eq(convert('128MB'), 128*1024*1024)
-        eq(convert('128GB'), 128*1024*1024*1024L)
+        eq(convert('128GB'), 128*1024*1024*1024)
         raises(ValueError, convert, '128TB')
         eq(convert('128'), 128)
         eq(convert('128kb'), 128*1024)
         eq(convert('128mb'), 128*1024*1024)
-        eq(convert('128gb'), 128*1024*1024*1024L)
+        eq(convert('128gb'), 128*1024*1024*1024)
         raises(ValueError, convert, '128tb')
 
     def test_time_interval(self):
